package com.example.testktor

import android.os.Bundle
import android.util.Log
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.runtime.*
import androidx.compose.ui.Modifier
import androidx.compose.ui.tooling.preview.Preview
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import com.example.matuletest.ui.auth.FirstScreen
import com.example.matuletest.ui.auth.SliderScreen
import com.example.testktor.screen.auth.AuthScreen
import com.example.testktor.screen.auth.ForgotPasswordScreen
import com.example.testktor.screen.auth.MainSneakersScreen
import com.example.testktor.screen.auth.RegScreen
import com.example.testktor.screen.auth.ResetPasswordScreen
//import com.example.testktor.auth.AuthScreen
//import com.example.testktor.auth.RegistrationScreen
import com.example.testktor.ui.theme.TestKtorTheme
import io.ktor.client.*
import io.ktor.client.request.*
import io.ktor.client.engine.android.*
import io.ktor.client.plugins.contentnegotiation.*
import io.ktor.client.statement.HttpResponse
import io.ktor.client.statement.bodyAsText
import io.ktor.http.ContentType
import io.ktor.http.contentType
import kotlinx.coroutines.launch
import kotlinx.serialization.Serializable
import io.ktor.serialization.kotlinx.json.*
import kotlinx.serialization.decodeFromString
import kotlinx.serialization.json.Json

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        setContent {
            TestKtorTheme {
                val navController = rememberNavController()

                NavHost(navController = navController, startDestination = "first_screen") {
                    composable("first_screen") {
                        FirstScreen(onNavigateToSliderScreen = {
                            navController.navigate("slider_screen")
                        })
                    }
                    composable("slider_screen") {
                        SliderScreen(onNavigateToAuthScreen = {
                            navController.navigate("auth_screen")
                        })
                    }
                    composable("auth_screen") {
                        AuthScreen(navController)
                    }
                    composable("registration_screen") {
                        RegScreen(navController)
                    }
                    composable("resetPassword_screen") {
                        ResetPasswordScreen(navController)
                    }
                    composable("forgotPassword_screen") {
                        ForgotPasswordScreen(navController)
                    }
                    composable("mainSneakers_screen") {
                        MainSneakersScreen(navController)
                    }
                }
            }
        }
    }
}

