package com.example.testktor.screen.auth

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.testktor.authUser
import com.example.testktor.resetPassword
import io.ktor.client.HttpClient
import io.ktor.client.engine.android.Android

@Composable
fun ResetPasswordScreen(navController: NavController) {
    var resetSuccess by remember { mutableStateOf<String?>(null) }
    var code by remember { mutableStateOf("") }
    var newPassword by remember { mutableStateOf("") }

    val client = HttpClient(Android)

    LaunchedEffect(code, newPassword) {
        if (code.isNotEmpty() && newPassword.isNotEmpty()) {
            val result = resetPassword(client, code, newPassword)
            resetSuccess = if (result) "Success" else "Failed"
        }
    }

    ResetPasswordContent(navController, resetSuccess, code, newPassword) { newCode, newNewPassword ->
        code = newCode
        newPassword = newNewPassword
    }
}

@Composable
fun ResetPasswordContent(
    navController: NavController,
    resetSuccess: String?,
    code: String,
    newPassword: String,
    onReset: (String, String) -> Unit
) {
    var codeIn by remember { mutableStateOf(code) }
    var newPasswordIn by remember { mutableStateOf(newPassword) }

    Column(
        modifier = Modifier.fillMaxSize(),
        horizontalAlignment = Alignment.CenterHorizontally,
        verticalArrangement = Arrangement.Center
    ) {
        // Отображение текста "Success" в левом верхнем углу
        if (resetSuccess != null){
            if (resetSuccess == "Success") {
                Text(
                    text = "Success",
                    modifier = Modifier
                        .padding(start = 16.dp, top = 16.dp)
                        .align(Alignment.Start),
                    color = Color.Green,
                    style = TextStyle(fontSize = 18.sp, fontWeight = FontWeight.Bold)
                )
            } else{
                Text(
                    text = "Error",
                    modifier = Modifier
                        .padding(start = 16.dp, top = 16.dp)
                        .align(Alignment.Start),
                    color = Color.Green,
                    style = TextStyle(fontSize = 18.sp, fontWeight = FontWeight.Bold)
                )
            }
        }

        Text(
            text = "ОТР Проверка",
            style = TextStyle(fontSize = 32.sp, fontWeight = FontWeight.Bold),
            modifier = Modifier.height(60.dp).padding(bottom = 20.dp)
        )

        Text(
            text = "Пожалуйста, проверьте свою электронную почту, чтобы увидеть код подтверждения",
            modifier = Modifier
                .fillMaxWidth()
                .padding(bottom = 20.dp),
            style = TextStyle(fontSize = 16.sp),
            textAlign = TextAlign.Center,
            maxLines = 3
        )

        Text(text = "OTP Code", modifier = Modifier.padding(end = 255.dp))
        TextField(
            modifier = Modifier.width(300.dp).height(70.dp).padding(bottom = 16.dp),
            value = codeIn,
            onValueChange = { codeIn = it }
        )

        Text(text = "New Password", modifier = Modifier.padding(end = 255.dp))
        TextField(
            modifier = Modifier.width(300.dp).height(70.dp).padding(bottom = 16.dp),
            value = newPasswordIn,
            onValueChange = { newPasswordIn = it }
        )

        Button(
            modifier = Modifier.width(350.dp).height(50.dp),
            colors = androidx.compose.material3.ButtonDefaults.buttonColors(
                containerColor = Color(0xFF48B2E7),
                contentColor = Color.White
            ),
            onClick = { onReset(codeIn, newPasswordIn) }
        ) {
            Text("Восстановить")
        }
    }
}
